from __future__ import print_function
from __future__ import unicode_literals

import pytest
import boto3
import os
import json
from moto import mock_s3
from s3_environ import S3Environ


class TestS3Environ(object):
    FILE = {
        'string_value': 'string here',
        'number_value': 1,
        'boolean_value': True,
        'array_value': ['zero', 1, 2],
        'dict_value': {
            'key': 'value',
        }
    }

    @mock_s3
    def test_get_s3_object(self):
        conn = boto3.resource('s3', region_name='us-east-1')
        conn.create_bucket(Bucket='test')
        conn.Object('test', 'vars.json').put(Body=json.dumps(self.FILE))

        s3_environ = S3Environ(bucket='test', key='vars.json')
        output = s3_environ.get_s3_object()
        assert output == self.FILE

    @mock_s3
    def test_set_variables(self):
        conn = boto3.resource('s3', region_name='us-east-1')
        conn.create_bucket(Bucket='test')
        conn.Object('test', 'vars.json').put(Body=json.dumps(self.FILE))

        S3Environ(bucket='test', key='vars.json')

        for key, value in self.FILE.items():
            assert os.environ.get(key) == str(value)

    @mock_s3
    def test_get_s3_object_error(self):
        with pytest.raises(Exception):
            S3Environ(bucket='test', key='vars.json')

    @mock_s3
    def test_get_s3_object_decode_error(self):
        conn = boto3.resource('s3', region_name='us-east-1')
        conn.create_bucket(Bucket='test')
        conn.Object('test', 'vars.json').put(Body='simple_string')

        with pytest.raises(ValueError):
            S3Environ(bucket='test', key='vars.json')



import os
import boto3
import json


class S3Environ(object):
    """
    Sets environment variables from an AWS S3 JSON file.
    """

    def __init__(self, bucket, key):
        """
        Instanciate the object with its bucket name and key.

        Arguments:
        <str> bucket - An S3 bucket.
        <key> key - An S3 object's key.

        Returns nothing.
        """

        self.bucket = bucket
        self.key = key
        self.set_variables()

    def get_s3_object(self):
        """
        Gets the file from AWS S3.

        Returns a dictionary with the file's content.
        """

        s3 = boto3.resource('s3')

        try:
            obj = s3.Object(
                bucket_name=self.bucket,
                key=self.key,

            ).get()['Body'].read()
        except Exception:
            print('Could not get file from AWS S3.')
            raise

        try:
            obj_content = json.loads(obj.decode('utf-8'))
        except ValueError:
            print('The file is not JSON valid.')
            raise

        return obj_content

    def set_variables(self):
        """
        Sets all environment variables defined in the file.
        """

        vars = self.get_s3_object()

        for key, value in vars.items():
            os.environ.setdefault(key, str(value))



from setuptools import setup, find_packages


setup(
    author='Jonatas Baldin',
    author_email='jonatas.baldin@gmail.com',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'Topic :: Utilities'
    ],
    description='Load environment variables from a AWS S3 file!',
    license='MIT License',
    url='https://github.com/jonatasbaldin/s3-environ',
    include_package_data=True,
    install_requires=['boto3'],
    name='s3-environ',
    packages=find_packages(),
    version='0.0.5'
)
